@@ -25,7 +25,6 @@ import math
 import re
 from datetime import date, datetime, timedelta
 from enum import Enum
-from typing import List, Literal, Tuple, Union
 
 from backports.datetime_fromisoformat import MonkeyPatch
 from dateutil.relativedelta import relativedelta
@@ -132,10 +131,7 @@ def next_period_date(period_date: date, frequency: Frequency):
         assert False, frequency
 
 
-Value = Union[float, Literal["NA"]]
-
-
-def align_series_list(series_list: List[Tuple[List[date], List[Value]]]):
+def align_series_list(series_list):
     """Align many series.
 
     Many series are aligned if they share a common list of periods.
