@@ -48,7 +48,7 @@ log = logging.getLogger(__name__)
 
 
 class GitStorage(AbstractStorage):
-    def __init__(self, repo, provider_code=None, git_ref='HEAD', tree=None, **kwargs):
+    def __init__(self, repo, provider_code=None, git_ref="HEAD", tree=None, **kwargs):
         self.repo = repo
         self.provider_code = provider_code
         self.git_ref = git_ref
@@ -62,7 +62,12 @@ class GitStorage(AbstractStorage):
 
     def __repr__(self):
         return "{}({!r}, provider_code={!r}, git_ref={!r}, tree={!r})".format(
-            self.__class__.__name__, self.repo, self.provider_code, self.git_ref, self.tree)
+            self.__class__.__name__,
+            self.repo,
+            self.provider_code,
+            self.git_ref,
+            self.tree,
+        )
 
     def has_file(self, name):
         return tree_has_blob(self.tree, name)
@@ -81,7 +86,9 @@ class GitStorage(AbstractStorage):
         entry_name = "provider.json"
         provider_json = load_json_blob(self.repo, self.tree, entry_name)
         if provider_json is None:
-            raise StorageError("Could not load \"{}\"".format(entry_name), self.provider_code)
+            raise StorageError(
+                'Could not load "{}"'.format(entry_name), self.provider_code
+            )
         return provider_json
 
     def load_releases_json(self):
@@ -107,10 +114,15 @@ class GitDatasetDir(AbstractDatasetDir):
         self._tree = dataset_tree
 
     def get_nb_series_from_jsonl(self, series_jsonl_file_name):
-        series_jsonl_text = load_text_blob(self.storage.repo, self.tree, series_jsonl_file_name)
+        series_jsonl_text = load_text_blob(
+            self.storage.repo, self.tree, series_jsonl_file_name
+        )
         if series_jsonl_text is None:
-            raise StorageError("Could not load \"{}\"".format(series_jsonl_file_name),
-                               self.storage.provider_code, self.dataset_code)
+            raise StorageError(
+                'Could not load "{}"'.format(series_jsonl_file_name),
+                self.storage.provider_code,
+                self.dataset_code,
+            )
         with StringIO(series_jsonl_text) as fp:
             nb_series = sum(1 for line in fp if line.strip())
         return nb_series
@@ -126,13 +138,19 @@ class GitDatasetDir(AbstractDatasetDir):
 
     def iter_observations_from_jsonl(self, series_codes, offset_by_series_code={}):
         raise NotImplementedError(
-            "Reading observations from JSON lines file is not supported with GitStorage. Use FileSystemStorage instead.")
+            "Reading observations from JSON lines file is not supported with GitStorage. Use FileSystemStorage instead."
+        )
 
     def iter_series_json_from_jsonl(self, series_jsonl_file_name, add_metadata=False):
-        series_jsonl_text = load_text_blob(self.storage.repo, self.tree, series_jsonl_file_name)
+        series_jsonl_text = load_text_blob(
+            self.storage.repo, self.tree, series_jsonl_file_name
+        )
         if series_jsonl_text is None:
-            raise StorageError("Could not load \"{}\"".format(series_jsonl_file_name),
-                               self.storage.provider_code, self.dataset_code)
+            raise StorageError(
+                'Could not load "{}"'.format(series_jsonl_file_name),
+                self.storage.provider_code,
+                self.dataset_code,
+            )
         with StringIO(series_jsonl_text) as fp:
             if add_metadata:
                 for line, offset in files.iter_line_offset(fp):
@@ -147,8 +165,11 @@ class GitDatasetDir(AbstractDatasetDir):
         entry_name = "dataset.json"
         dataset_json = load_json_blob(self.storage.repo, self.tree, entry_name)
         if dataset_json is None:
-            raise StorageError("Could not load \"{}\"".format(entry_name),
-                               self.storage.provider_code, self.dataset_code)
+            raise StorageError(
+                'Could not load "{}"'.format(entry_name),
+                self.storage.provider_code,
+                self.dataset_code,
+            )
         return dataset_json
 
     def load_observations_tsv(self, series_code):
@@ -156,24 +177,33 @@ class GitDatasetDir(AbstractDatasetDir):
         entry_name = "{}.tsv".format(series_code)
         observations_tsv = load_text_blob(self.storage.repo, self.tree, entry_name)
         if observations_tsv is None:
-            raise StorageError("Could not load \"{}\"".format(entry_name),
-                               self.storage.provider_code, self.dataset_code, series_code)
+            raise StorageError(
+                'Could not load "{}"'.format(entry_name),
+                self.storage.provider_code,
+                self.dataset_code,
+                series_code,
+            )
         return observations_tsv
 
     @property
     def tree(self):
         if self._tree is None:
-            self._tree = load_tree(self.storage.repo, self.storage.tree, self.dataset_code)
+            self._tree = load_tree(
+                self.storage.repo, self.storage.tree, self.dataset_code
+            )
             if self._tree is None:
-                raise StorageError("Could not load tree", self.storage.provider_code, self.dataset_code)
+                raise StorageError(
+                    "Could not load tree", self.storage.provider_code, self.dataset_code
+                )
         return self._tree
 
+
 # Generic Git read functions
 
 
 def get_commit_tree(repo, git_ref, path):
     try:
-        commit = repo[git_ref.encode('utf-8')]
+        commit = repo[git_ref.encode("utf-8")]
     except KeyError:
         return None
     commit_tree = commit.tree
@@ -188,13 +218,13 @@ def iter_children(tree, mode):
     for entry_name in tree:
         entry_type, child_tree_id = tree[entry_name]
         if entry_type == mode:
-            entry_name = entry_name.decode('utf-8')
+            entry_name = entry_name.decode("utf-8")
             yield (entry_name, child_tree_id)
 
 
 def load_json_blob(repo, tree, entry_name):
     if isinstance(entry_name, str):
-        entry_name = entry_name.encode('utf-8')
+        entry_name = entry_name.encode("utf-8")
     blob_str = load_text_blob(repo, tree, entry_name)
     if blob_str is None:
         return None
@@ -207,7 +237,7 @@ def load_json_blob(repo, tree, entry_name):
 
 def load_text_blob(repo, tree, entry_name, decode=True):
     if isinstance(entry_name, str):
-        entry_name = entry_name.encode('utf-8')
+        entry_name = entry_name.encode("utf-8")
     try:
         entry_mode, entry_id = tree[entry_name]
     except KeyError:
@@ -218,7 +248,7 @@ def load_text_blob(repo, tree, entry_name, decode=True):
     if not decode:
         return blob_data
     try:
-        blob_str = blob_data.decode('utf-8')
+        blob_str = blob_data.decode("utf-8")
     except UnicodeDecodeError:
         return None
     return blob_str
@@ -226,7 +256,7 @@ def load_text_blob(repo, tree, entry_name, decode=True):
 
 def load_tree(repo, tree, entry_name):
     if isinstance(entry_name, str):
-        entry_name = entry_name.encode('utf-8')
+        entry_name = entry_name.encode("utf-8")
     try:
         entry_mode, entry_id = tree[entry_name]
     except KeyError:
@@ -238,7 +268,7 @@ def load_tree(repo, tree, entry_name):
 
 def tree_has_blob(tree, entry_name):
     if isinstance(entry_name, str):
-        entry_name = entry_name.encode('utf-8')
+        entry_name = entry_name.encode("utf-8")
     try:
         entry_type, _ = tree[entry_name]
     except KeyError:
@@ -251,9 +281,9 @@ def tree_has_blob(tree, entry_name):
 
 def add_blob_to_tree(repo, tree, entry_name, text):
     if isinstance(entry_name, str):
-        entry_name = entry_name.encode('utf-8')
+        entry_name = entry_name.encode("utf-8")
     if isinstance(text, str):
-        text = text.encode('utf-8')
+        text = text.encode("utf-8")
     assert entry_name, entry_name
     blob = Blob.from_string(text)
     repo.object_store.add_object(blob)
@@ -262,7 +292,7 @@ def add_blob_to_tree(repo, tree, entry_name, text):
 
 def add_tree_to_tree(repo, tree, entry_name, child_tree):
     if isinstance(entry_name, str):
-        entry_name = entry_name.encode('utf-8')
+        entry_name = entry_name.encode("utf-8")
     assert entry_name, entry_name
     repo.object_store.add_object(child_tree)
     tree.add(entry_name, git_tree_filemode, child_tree.id)
